// requires Base.js
var AE = window.AE || {};



AE.TextureResizer = function(self) {



// Short handle for selector function.
var $ = AE.$;



// Object to hold options.
var Options = self.Options = {};



self.initialize = function(opt) {
  // Load the options.
  if (!opt) { opt = {}; }
  for (var i in opt) { Options[i] = opt[i]; }
  if (Options.debug) { AE.debug = Options.debug; }

  // Load defaults.
  AE.Form.fill(opt, $("#options"));

  // Loop over all nested inputs and apply event hander for toggleDisabled.
  var inputs = $("input", $("#options"));
  for (var j=0; j< inputs.length; j++) {
    var input = inputs[j];
    if (input.type == "radio" || input.type == "checkbox") {
      input.onclick = function() { toggleDisabled(this) };
      toggleDisabled(input);
    };
  };

  // Cancel button.
  $("#cancel_button").onclick = function() {
    AE.Dialog.close();
  };

  // OK button.
  $("#apply_button").onclick = function() {
    AE.Bridge.updateOptions(AE.Form.read());
  };

  // Prevent page reloading on buttons in form element. (At the moment there are no buttons.)
  $("#options").onsubmit = function() { return false; };

  // Adjust the size (height) when the dialog has been manually resized.
  // In Internet Explorer it requires a little delay to complete resizing because it triggers
  // onresize twice (for height & width). Otherwise we would use incorrect
  // dimensions and the dialog flickers.
  window.onresize = function(){ window.setTimeout(AE.Dialog.adjustSize, 0) };

  // Adjust the size of the dialog.
  AE.Dialog.adjustSize();
};



/** Disable or enable input elements in cascaded forms.
 *    Args:
 *      input:
 *      1) A checkbox or radio button that has an rel="c1" attribute pointing at
 *         the id of another input/container that should be disabled/enabled.
 *         <somewhere> <checkbox rel="c1"> </somewhere> ...
 *         <somewhereelse> <container id="c1"> <input> </container> </somewhereelse>
 *      2) A container that has only one checkbox/radio button as direct child element.
 *         All other inputs cascaded in subcontainers of this container will be disabled/enabled.
 *         <container> <checkbox> <subcontainer1> <input> </subcontainer1> </container>
 *     Returns:
 *       nothing
 */
var toggleDisabled = function(input) {
  //
  var toggleChildren = function(input) {
    // Look for rel attribute.
    if (input.getAttribute('rel')) {
      // Get the container.
      var relContainer = $("#" + input.getAttribute('rel'));
      relContainer.disabled = !input.checked;
      // Loop over all children of relContainer and set their disabled status.
      var relInputs = $('input', relContainer);
      for (var i=0; i<relInputs.length; i++) {
        relInputs[i].disabled = !input.checked;
      }
    // Parent element must have only one child input and several sub-containers.
    } else {
      // Get all containers that should be enabled/disabled.
      var c = input.parentNode.childNodes
      // If this input is wrapped in a label, then the parent that we want is outside.
      if (input.parentNode.nodeName == "LABEL") {
        c = input.parentNode.parentNode.childNodes;
      }
      var n = []; // Collects a boolean input (Should only contain one element.)
      // Get the boolean input that decides over the subcontainers' disabled state.
      for (var i=0; i<c.length; i++) {
        // Boolean input (checkbox/radio).
        if (c[i].nodeName == "INPUT" &&
            (c[i].type == "checkbox" || c[i].type=="radio")) {
          n.push(c[i]);
        }
        // Nested boolean input inside a label (checkbox/radio).
        else if (c[i].nodeName == "LABEL") {
          var d = c[i].childNodes;
          for (var j=0; j<d.length; j++) {
            if (d[j].nodeName == "INPUT" &&
                (d[j].type == "checkbox" || d[j].type == "radio")) {
              n.push(d[j]);
              break;
            }
          }
        }
      }
      // Toggle the disabled state for all inputs in all containers according to n[0].
      if (n.length == 1) {
        for (var i=0; i<c.length; i++) {
          if (c[i].childNodes.length == 0) { continue; }
          var ci = c[i].getElementsByTagName('input');
          for (var k=0; k<ci.length; k++) {
            if (!(ci[k] == input)) {
              ci[k].disabled = !input.checked;
            }
          }
        }
      }
    }
  }
  toggleChildren(input);
  // radio: Loop over all connected radio buttons (with same name).
  if (input.type == 'radio') {
    var radios = document.getElementsByName(input.name);
    for (var i=0; i<radios.length; i++) {
      if (radios[i] != input) { toggleChildren(radios[i]); }
    }
  }
};



/* module Progress
 * A primitive progress indicator.
 */
self.Progress = function(progress) {

  // Show progress animation.
  progress.start = function() {
    AE.Style.show( $("#overlay") );
  }

  // Hide progress animation.
  progress.end = function() {
    AE.Style.hide( $("#overlay") );
  }

  return progress;
}(self.Progress || {});; // end module Progress



return self;
}(AE.TextureResizer || {}); // end module TextureResizer



// Catch errors in the WebDialog and send them to the Ruby Console
/*window.onerror = function(errorMsg, url, lineNumber){
  AE.Bridge.puts("JavaScript error:\n"+url+" (line "+lineNumber+"): "+errorMsg);
  return true;
}*/
